@@ -1,4 +1,4 @@
-create table #dblib0016 (f1 int not null, f2 text, f3 varchar(20) )
+create table #dblib0016 (f1 int not null, f2 char(20) not null, f3 binary(4) not null)
 go
 select * from #dblib0016 where 0=1
 go
